@@ -692,14 +692,15 @@ def create_config(project: Project, optim: ProjectOptimization, framework: str)
     # add imports in function so they don't fail if they don't have env setup
     # for frameworks other than the requested
     if framework == "pytorch":
-        from sparseml.pytorch.optim import (
+        from sparseml.pytorch.optim.manager import ScheduledModifierManager
+        from sparseml.pytorch.sparsification import (
             EpochRangeModifier,
             GMPruningModifier,
             LearningRateModifier,
-            ScheduledModifierManager,
             SetLearningRateModifier,
             TrainableParamsModifier,
         )
+
     elif framework == "tensorflow":
         from sparseml.tensorflow_v1.optim import (
             EpochRangeModifier,
